@@ -2,5 +2,7 @@ from sqlalchemy_api_handler.api_errors import ApiErrors
 from sqlalchemy_api_handler.api_handler import ApiHandler
 from sqlalchemy_api_handler.serialization.as_dict import as_dict
 from sqlalchemy_api_handler.utils.human_ids import humanize, dehumanize
+from sqlalchemy_api_handler.utils.listify import listify
+from sqlalchemy_api_handler.utils.load_or_404 import load_or_404
 
-__version__ = "0.0.11"
+__version__ = "0.0.13"
